[gimp] app: rename more stuff from "floating sel" to "floating selection"



commit 2ef8719cbe59f27ebf945b0c5c5c19fef49fa7ad
Author: Michael Natterer <mitch gimp org>
Date:   Fri May 20 16:46:26 2016 +0200

    app: rename more stuff from "floating sel" to "floating selection"

 app/actions/layers-actions.c                       |    2 +-
 app/actions/layers-commands.c                      |    2 +-
 app/core/Makefile.am                               |    8 ++--
 app/core/core-types.h                              |    1 -
 app/core/gimp-edit.c                               |    2 +-
 app/core/gimpdrawable-transform.c                  |    2 +-
 ...oatingselundo.c => gimpfloatingselectionundo.c} |   48 ++++++++++--------
 app/core/gimpfloatingselectionundo.h               |   52 ++++++++++++++++++++
 app/core/gimpfloatingselundo.h                     |   51 -------------------
 app/core/gimpimage-duplicate.c                     |    2 +-
 app/core/gimpimage-merge.c                         |    2 +-
 app/core/gimpimage-quick-mask.c                    |    2 +-
 app/core/gimpimage-undo-push.c                     |    4 +-
 app/core/gimpimage.c                               |    2 +-
 ...oating-sel.c => gimplayer-floating-selection.c} |    2 +-
 ...oating-sel.h => gimplayer-floating-selection.h} |    6 +-
 app/core/gimplayer.c                               |    2 +-
 app/core/gimpselection.c                           |    2 +-
 app/display/gimpcanvaslayerboundary.c              |    2 +-
 app/pdb/floating-sel-cmds.c                        |    2 +-
 app/text/gimptext-compat.c                         |    2 +-
 app/tools/gimpfreeselecttool.c                     |    2 +-
 app/tools/gimpmovetool.c                           |    2 +-
 app/tools/gimprectangleselecttool.c                |    6 +-
 app/tools/gimpregionselecttool.c                   |    2 +-
 app/tools/gimptexttool.c                           |    2 +-
 app/xcf/xcf-load.c                                 |    2 +-
 po/POTFILES.in                                     |    2 +-
 tools/pdbgen/pdb/floating_sel.pdb                  |    2 +-
 29 files changed, 112 insertions(+), 106 deletions(-)
---
diff --git a/app/actions/layers-actions.c b/app/actions/layers-actions.c
index 4df1a47..11f3f84 100644
--- a/app/actions/layers-actions.c
+++ b/app/actions/layers-actions.c
@@ -27,7 +27,7 @@
 #include "core/gimpchannel.h"
 #include "core/gimpimage.h"
 #include "core/gimplayer.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 
 #include "text/gimptextlayer.h"
 
diff --git a/app/actions/layers-commands.c b/app/actions/layers-commands.c
index 0ce9f9e..e90723a 100644
--- a/app/actions/layers-commands.c
+++ b/app/actions/layers-commands.c
@@ -41,7 +41,7 @@
 #include "core/gimpimage-undo.h"
 #include "core/gimpimage-undo-push.h"
 #include "core/gimpitemundo.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 #include "core/gimplayer-new.h"
 #include "core/gimppickable.h"
 #include "core/gimppickable-auto-shrink.h"
diff --git a/app/core/Makefile.am b/app/core/Makefile.am
index 1be6439..5f9081d 100644
--- a/app/core/Makefile.am
+++ b/app/core/Makefile.am
@@ -192,8 +192,8 @@ libappcore_a_sources = \
        gimpfilteredcontainer.h                 \
        gimpfilterstack.c                       \
        gimpfilterstack.h                       \
-       gimpfloatingselundo.c                   \
-       gimpfloatingselundo.h                   \
+       gimpfloatingselectionundo.c             \
+       gimpfloatingselectionundo.h             \
        gimpgradient.c                          \
        gimpgradient.h                          \
        gimpgradient-load.c                     \
@@ -295,8 +295,8 @@ libappcore_a_sources = \
        gimpitemundo.h                          \
        gimplayer.c                             \
        gimplayer.h                             \
-       gimplayer-floating-sel.c                \
-       gimplayer-floating-sel.h                \
+       gimplayer-floating-selection.c          \
+       gimplayer-floating-selection.h          \
        gimplayer-new.c                         \
        gimplayer-new.h                         \
        gimplayermask.c                         \
diff --git a/app/core/core-types.h b/app/core/core-types.h
index 4249dcc..9462fd7 100644
--- a/app/core/core-types.h
+++ b/app/core/core-types.h
@@ -170,7 +170,6 @@ typedef struct _GimpGroupLayerUndo    GimpGroupLayerUndo;
 typedef struct _GimpMaskUndo          GimpMaskUndo;
 typedef struct _GimpGuideUndo         GimpGuideUndo;
 typedef struct _GimpSamplePointUndo   GimpSamplePointUndo;
-typedef struct _GimpFloatingSelUndo   GimpFloatingSelUndo;
 typedef struct _GimpUndoStack         GimpUndoStack;
 typedef struct _GimpUndoAccumulator   GimpUndoAccumulator;
 
diff --git a/app/core/gimp-edit.c b/app/core/gimp-edit.c
index 57fb54a..94124c5 100644
--- a/app/core/gimp-edit.c
+++ b/app/core/gimp-edit.c
@@ -41,7 +41,7 @@
 #include "gimpimage.h"
 #include "gimpimage-undo.h"
 #include "gimplayer.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimplayer-new.h"
 #include "gimplist.h"
 #include "gimppattern.h"
diff --git a/app/core/gimpdrawable-transform.c b/app/core/gimpdrawable-transform.c
index 844da51..c2d6ab5 100644
--- a/app/core/gimpdrawable-transform.c
+++ b/app/core/gimpdrawable-transform.c
@@ -42,7 +42,7 @@
 #include "gimpimage-undo.h"
 #include "gimpimage-undo-push.h"
 #include "gimplayer.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimplayer-new.h"
 #include "gimppickable.h"
 #include "gimpprogress.h"
diff --git a/app/core/gimpfloatingselectionundo.h b/app/core/gimpfloatingselectionundo.h
new file mode 100644
index 0000000..a08c462
--- /dev/null
+++ b/app/core/gimpfloatingselectionundo.h
@@ -0,0 +1,52 @@
+/* GIMP - The GNU Image Manipulation Program
+ * Copyright (C) 1995 Spencer Kimball and Peter Mattis
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+#ifndef __GIMP_FLOATING_SELECTION_UNDO_H__
+#define __GIMP_FLOATING_SELECTION_UNDO_H__
+
+
+#include "gimpitemundo.h"
+
+
+#define GIMP_TYPE_FLOATING_SELECTION_UNDO            (gimp_floating_selection_undo_get_type ())
+#define GIMP_FLOATING_SELECTION_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), 
GIMP_TYPE_FLOATING_SELECTION_UNDO, GimpFloatingSelectionUndo))
+#define GIMP_FLOATING_SELECTION_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), 
GIMP_TYPE_FLOATING_SELECTION_UNDO, GimpFloatingSelectionUndoClass))
+#define GIMP_IS_FLOATING_SELECTION_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), 
GIMP_TYPE_FLOATING_SELECTION_UNDO))
+#define GIMP_IS_FLOATING_SELECTION_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), 
GIMP_TYPE_FLOATING_SELECTION_UNDO))
+#define GIMP_FLOATING_SELECTION_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), 
GIMP_TYPE_FLOATING_SELECTION_UNDO, GimpFloatingSelectionUndoClass))
+
+
+typedef struct _GimpFloatingSelectionUndo      GimpFloatingSelectionUndo;
+typedef struct _GimpFloatingSelectionUndoClass GimpFloatingSelectionUndoClass;
+
+struct _GimpFloatingSelectionUndo
+{
+  GimpItemUndo  parent_instance;
+
+  GimpDrawable *drawable;
+};
+
+struct _GimpFloatingSelectionUndoClass
+{
+  GimpItemUndoClass  parent_class;
+};
+
+
+GType   gimp_floating_selection_undo_get_type (void) G_GNUC_CONST;
+
+
+#endif /* __GIMP_FLOATING_SELECTION_UNDO_H__ */
diff --git a/app/core/gimpimage-duplicate.c b/app/core/gimpimage-duplicate.c
index ba934b2..fc62bad 100644
--- a/app/core/gimpimage-duplicate.c
+++ b/app/core/gimpimage-duplicate.c
@@ -40,7 +40,7 @@
 #include "gimpitemstack.h"
 #include "gimplayer.h"
 #include "gimplayermask.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimpparasitelist.h"
 #include "gimpsamplepoint.h"
 
diff --git a/app/core/gimpimage-merge.c b/app/core/gimpimage-merge.c
index b73eddc..4f040a1 100644
--- a/app/core/gimpimage-merge.c
+++ b/app/core/gimpimage-merge.c
@@ -42,7 +42,7 @@
 #include "gimpimage-merge.h"
 #include "gimpimage-undo.h"
 #include "gimpitemstack.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimplayer-new.h"
 #include "gimplayermask.h"
 #include "gimpmarshal.h"
diff --git a/app/core/gimpimage-quick-mask.c b/app/core/gimpimage-quick-mask.c
index e26352f..bc13090 100644
--- a/app/core/gimpimage-quick-mask.c
+++ b/app/core/gimpimage-quick-mask.c
@@ -33,7 +33,7 @@
 #include "gimpimage-undo.h"
 #include "gimpimage-undo-push.h"
 #include "gimplayer.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimpselection.h"
 
 #include "gimp-intl.h"
diff --git a/app/core/gimpimage-undo-push.c b/app/core/gimpimage-undo-push.c
index f57d941..86f9aed 100644
--- a/app/core/gimpimage-undo-push.c
+++ b/app/core/gimpimage-undo-push.c
@@ -29,7 +29,7 @@
 #include "gimpchannelundo.h"
 #include "gimpdrawablemodundo.h"
 #include "gimpdrawableundo.h"
-#include "gimpfloatingselundo.h"
+#include "gimpfloatingselectionundo.h"
 #include "gimpgrid.h"
 #include "gimpgrouplayer.h"
 #include "gimpgrouplayerundo.h"
@@ -922,7 +922,7 @@ gimp_image_undo_push_fs_to_layer (GimpImage    *image,
   g_return_val_if_fail (GIMP_IS_IMAGE (image), NULL);
   g_return_val_if_fail (GIMP_IS_LAYER (floating_layer), NULL);
 
-  undo = gimp_image_undo_push (image, GIMP_TYPE_FLOATING_SEL_UNDO,
+  undo = gimp_image_undo_push (image, GIMP_TYPE_FLOATING_SELECTION_UNDO,
                                GIMP_UNDO_FS_TO_LAYER, undo_desc,
                                GIMP_DIRTY_IMAGE_STRUCTURE,
                                "item", floating_layer,
diff --git a/app/core/gimpimage.c b/app/core/gimpimage.c
index f8d22f0..0383f9d 100644
--- a/app/core/gimpimage.c
+++ b/app/core/gimpimage.c
@@ -62,7 +62,7 @@
 #include "gimpimage-undo-push.h"
 #include "gimpitemtree.h"
 #include "gimplayer.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimplayermask.h"
 #include "gimpmarshal.h"
 #include "gimpparasitelist.h"
diff --git a/app/core/gimplayer-floating-sel.c b/app/core/gimplayer-floating-selection.c
similarity index 99%
rename from app/core/gimplayer-floating-sel.c
rename to app/core/gimplayer-floating-selection.c
index d83fa28..6667a1e 100644
--- a/app/core/gimplayer-floating-sel.c
+++ b/app/core/gimplayer-floating-selection.c
@@ -32,7 +32,7 @@
 #include "gimpimage-undo.h"
 #include "gimpimage-undo-push.h"
 #include "gimplayer.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimplayermask.h"
 
 #include "gimp-intl.h"
diff --git a/app/core/gimplayer-floating-sel.h b/app/core/gimplayer-floating-selection.h
similarity index 91%
rename from app/core/gimplayer-floating-sel.h
rename to app/core/gimplayer-floating-selection.h
index d66114c..6366f24 100644
--- a/app/core/gimplayer-floating-sel.h
+++ b/app/core/gimplayer-floating-selection.h
@@ -15,8 +15,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_LAYER_FLOATING_SEL_H__
-#define __GIMP_LAYER_FLOATING_SEL_H__
+#ifndef __GIMP_LAYER_FLOATING_SELECTION_H__
+#define __GIMP_LAYER_FLOATING_SELECTION_H__
 
 
 void                 floating_sel_attach            (GimpLayer     *layer,
@@ -30,4 +30,4 @@ const GimpBoundSeg * floating_sel_boundary          (GimpLayer     *layer,
 void                 floating_sel_invalidate        (GimpLayer     *layer);
 
 
-#endif /* __GIMP_LAYER_FLOATING_SEL_H__ */
+#endif /* __GIMP_LAYER_FLOATING_SELECTION_H__ */
diff --git a/app/core/gimplayer.c b/app/core/gimplayer.c
index f066d6a..b6856eb 100644
--- a/app/core/gimplayer.c
+++ b/app/core/gimplayer.c
@@ -46,7 +46,7 @@
 #include "gimpimage-undo.h"
 #include "gimpimage.h"
 #include "gimpimage-color-profile.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimplayer.h"
 #include "gimplayermask.h"
 #include "gimpmarshal.h"
diff --git a/app/core/gimpselection.c b/app/core/gimpselection.c
index 87a40fc..f113036 100644
--- a/app/core/gimpselection.c
+++ b/app/core/gimpselection.c
@@ -39,7 +39,7 @@
 #include "gimplayer.h"
 #include "gimplayer-new.h"
 #include "gimplayermask.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 #include "gimppickable.h"
 #include "gimpselection.h"
 
diff --git a/app/display/gimpcanvaslayerboundary.c b/app/display/gimpcanvaslayerboundary.c
index a5e444c..634bc5e 100644
--- a/app/display/gimpcanvaslayerboundary.c
+++ b/app/display/gimpcanvaslayerboundary.c
@@ -30,7 +30,7 @@
 
 #include "core/gimpchannel.h"
 #include "core/gimplayer.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 
 #include "gimpcanvas-style.h"
 #include "gimpcanvaslayerboundary.h"
diff --git a/app/pdb/floating-sel-cmds.c b/app/pdb/floating-sel-cmds.c
index be505fd..9ec2099 100644
--- a/app/pdb/floating-sel-cmds.c
+++ b/app/pdb/floating-sel-cmds.c
@@ -29,7 +29,7 @@
 
 #include "core/gimpdrawable.h"
 #include "core/gimpimage.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 #include "core/gimplayer.h"
 #include "core/gimpparamspecs.h"
 
diff --git a/app/text/gimptext-compat.c b/app/text/gimptext-compat.c
index 9c48c12..9eb6026 100644
--- a/app/text/gimptext-compat.c
+++ b/app/text/gimptext-compat.c
@@ -35,7 +35,7 @@
 #include "core/gimpdrawable.h"
 #include "core/gimpimage.h"
 #include "core/gimpimage-undo.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 
 #include "gimptext.h"
 #include "gimptext-compat.h"
diff --git a/app/tools/gimpfreeselecttool.c b/app/tools/gimpfreeselecttool.c
index 11131d7..3012e05 100644
--- a/app/tools/gimpfreeselecttool.c
+++ b/app/tools/gimpfreeselecttool.c
@@ -35,7 +35,7 @@
 #include "core/gimpchannel.h"
 #include "core/gimpchannel-select.h"
 #include "core/gimpimage.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 
 #include "widgets/gimphelp-ids.h"
 #include "widgets/gimpwidgets-utils.h"
diff --git a/app/tools/gimpmovetool.c b/app/tools/gimpmovetool.c
index 34969fc..c72f4f0 100644
--- a/app/tools/gimpmovetool.c
+++ b/app/tools/gimpmovetool.c
@@ -39,7 +39,7 @@
 #include "core/gimplayer.h"
 #include "core/gimpimage-undo.h"
 #include "core/gimplayermask.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 #include "core/gimpundostack.h"
 
 #include "widgets/gimphelp-ids.h"
diff --git a/app/tools/gimprectangleselecttool.c b/app/tools/gimprectangleselecttool.c
index b6ef0ef..9fe78a3 100644
--- a/app/tools/gimprectangleselecttool.c
+++ b/app/tools/gimprectangleselecttool.c
@@ -25,13 +25,13 @@
 
 #include "tools-types.h"
 
-#include "core/gimpchannel.h"
+#include "core/gimp-utils.h"
 #include "core/gimpchannel-select.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimpchannel.h"
 #include "core/gimpimage.h"
 #include "core/gimpimage-undo.h"
+#include "core/gimplayer-floating-selection.h"
 #include "core/gimppickable.h"
-#include "core/gimp-utils.h"
 #include "core/gimpundostack.h"
 
 #include "widgets/gimpdialogfactory.h"
diff --git a/app/tools/gimpregionselecttool.c b/app/tools/gimpregionselecttool.c
index 5c8c69e..4bc4a1a 100644
--- a/app/tools/gimpregionselecttool.c
+++ b/app/tools/gimpregionselecttool.c
@@ -31,7 +31,7 @@
 #include "core/gimpchannel.h"
 #include "core/gimpchannel-select.h"
 #include "core/gimpimage.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 
 #include "display/gimpdisplay.h"
 #include "display/gimpdisplayshell.h"
diff --git a/app/tools/gimptexttool.c b/app/tools/gimptexttool.c
index f023782..01cc9ba 100644
--- a/app/tools/gimptexttool.c
+++ b/app/tools/gimptexttool.c
@@ -37,7 +37,7 @@
 #include "core/gimpimage-pick-layer.h"
 #include "core/gimpimage-undo.h"
 #include "core/gimpimage-undo-push.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 #include "core/gimpmarshal.h"
 #include "core/gimptoolinfo.h"
 #include "core/gimpundostack.h"
diff --git a/app/xcf/xcf-load.c b/app/xcf/xcf-load.c
index 82ef7e5..f48558a 100644
--- a/app/xcf/xcf-load.c
+++ b/app/xcf/xcf-load.c
@@ -47,7 +47,7 @@
 #include "core/gimpimage-sample-points.h"
 #include "core/gimpimage-undo.h"
 #include "core/gimpitemstack.h"
-#include "core/gimplayer-floating-sel.h"
+#include "core/gimplayer-floating-selection.h"
 #include "core/gimplayer-new.h"
 #include "core/gimplayermask.h"
 #include "core/gimpparasitelist.h"
diff --git a/po/POTFILES.in b/po/POTFILES.in
index 5df36ac..324b9c5 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -160,7 +160,7 @@ app/core/gimpimagefile.c
 app/core/gimpitem.c
 app/core/gimpitem-exclusive.c
 app/core/gimpitem-linked.c
-app/core/gimplayer-floating-sel.c
+app/core/gimplayer-floating-selection.c
 app/core/gimplayer.c
 app/core/gimplayermask.c
 app/core/gimpmybrush-load.c
diff --git a/tools/pdbgen/pdb/floating_sel.pdb b/tools/pdbgen/pdb/floating_sel.pdb
index f5e1005..fc26cc3 100644
--- a/tools/pdbgen/pdb/floating_sel.pdb
+++ b/tools/pdbgen/pdb/floating_sel.pdb
@@ -200,7 +200,7 @@ CODE
 
 
 @headers = qw("core/gimpimage.h"
-              "core/gimplayer-floating-sel.h"
+              "core/gimplayer-floating-selection.h"
               "gimppdberror.h"
               "gimppdb-utils.h"
               "gimp-intl.h");


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/app/core/gimpfloatingselundo.c b/app/core/gimpfloatingselectionundo.c
similarity index 65%
rename from app/core/gimpfloatingselundo.c
rename to app/core/gimpfloatingselectionundo.c
index b7ff3d2..07e49e7 100644
--- a/app/core/gimpfloatingselundo.c
+++ b/app/core/gimpfloatingselectionundo.c
@@ -23,45 +23,48 @@
 #include "core-types.h"
 
 #include "gimpdrawable-floating-selection.h"
-#include "gimpfloatingselundo.h"
+#include "gimpfloatingselectionundo.h"
 #include "gimpimage.h"
 #include "gimplayer.h"
-#include "gimplayer-floating-sel.h"
+#include "gimplayer-floating-selection.h"
 
 
-static void   gimp_floating_sel_undo_constructed (GObject             *object);
+static void   gimp_floating_selection_undo_constructed (GObject             *object);
 
-static void   gimp_floating_sel_undo_pop         (GimpUndo            *undo,
-                                                  GimpUndoMode         undo_mode,
-                                                  GimpUndoAccumulator *accum);
+static void   gimp_floating_selection_undo_pop         (GimpUndo            *undo,
+                                                        GimpUndoMode         undo_mode,
+                                                        GimpUndoAccumulator *accum);
 
 
-G_DEFINE_TYPE (GimpFloatingSelUndo, gimp_floating_sel_undo, GIMP_TYPE_ITEM_UNDO)
+G_DEFINE_TYPE (GimpFloatingSelectionUndo, gimp_floating_selection_undo,
+               GIMP_TYPE_ITEM_UNDO)
 
-#define parent_class gimp_floating_sel_undo_parent_class
+#define parent_class gimp_floating_selection_undo_parent_class
 
 
 static void
-gimp_floating_sel_undo_class_init (GimpFloatingSelUndoClass *klass)
+gimp_floating_selection_undo_class_init (GimpFloatingSelectionUndoClass *klass)
 {
   GObjectClass  *object_class = G_OBJECT_CLASS (klass);
   GimpUndoClass *undo_class   = GIMP_UNDO_CLASS (klass);
 
-  object_class->constructed = gimp_floating_sel_undo_constructed;
+  object_class->constructed = gimp_floating_selection_undo_constructed;
 
-  undo_class->pop           = gimp_floating_sel_undo_pop;
+  undo_class->pop           = gimp_floating_selection_undo_pop;
 }
 
 static void
-gimp_floating_sel_undo_init (GimpFloatingSelUndo *undo)
+gimp_floating_selection_undo_init (GimpFloatingSelectionUndo *undo)
 {
 }
 
 static void
-gimp_floating_sel_undo_constructed (GObject *object)
+gimp_floating_selection_undo_constructed (GObject *object)
 {
-  GimpFloatingSelUndo *floating_sel_undo = GIMP_FLOATING_SEL_UNDO (object);
-  GimpLayer           *layer;
+  GimpFloatingSelectionUndo *floating_sel_undo;
+  GimpLayer                 *layer;
+
+  floating_sel_undo = GIMP_FLOATING_SELECTION_UNDO (object);
 
   G_OBJECT_CLASS (parent_class)->constructed (object);
 
@@ -81,12 +84,15 @@ gimp_floating_sel_undo_constructed (GObject *object)
 }
 
 static void
-gimp_floating_sel_undo_pop (GimpUndo            *undo,
-                            GimpUndoMode         undo_mode,
-                            GimpUndoAccumulator *accum)
+gimp_floating_selection_undo_pop (GimpUndo            *undo,
+                                  GimpUndoMode         undo_mode,
+                                  GimpUndoAccumulator *accum)
 {
-  GimpFloatingSelUndo *floating_sel_undo = GIMP_FLOATING_SEL_UNDO (undo);
-  GimpLayer           *floating_layer    = GIMP_LAYER (GIMP_ITEM_UNDO (undo)->item);
+  GimpFloatingSelectionUndo *floating_sel_undo;
+  GimpLayer                 *floating_layer;
+
+  floating_sel_undo = GIMP_FLOATING_SELECTION_UNDO (undo);
+  floating_layer    = GIMP_LAYER (GIMP_ITEM_UNDO (undo)->item);
 
   GIMP_UNDO_CLASS (parent_class)->pop (undo, undo_mode, accum);
 
@@ -95,7 +101,7 @@ gimp_floating_sel_undo_pop (GimpUndo            *undo,
     case GIMP_UNDO_FS_TO_LAYER:
       if (undo_mode == GIMP_UNDO_MODE_UNDO)
         {
           /*  Update the preview for the floating sel  */
           gimp_viewable_invalidate_preview (GIMP_VIEWABLE (floating_layer));
 
           gimp_layer_set_floating_sel_drawable (floating_layer,
@@ -95,7 +101,7 @@ gimp_floating_sel_undo_pop (GimpUndo            *undo,
       if (undo_mode == GIMP_UNDO_MODE_UNDO)
         {
-          /*  Update the preview for the floating sel  */
+          /*  Update the preview for the floating selection  */
           gimp_viewable_invalidate_preview (GIMP_VIEWABLE (floating_layer));
 